@@ -15,7 +15,7 @@ from pprint import pprint
 import numpy as np
 
 from cdftpy.cdft1d.config import DATA_DIR
-from cdftpy.cdft1d.io_utils import read_array, read_geom
+from cdftpy.cdft1d.io_utils import read_array, read_geom, write_matrix_array
 from cdftpy.cdft1d.io_utils import read_key_value
 from cdftpy.cdft1d.io_utils import read_system
 from cdftpy.utils.rad_fft import RadFFT
@@ -197,3 +197,4 @@ if __name__ == "__main__":
         s_k = solvent.s_k
     )
     solvent.to_smdl_file("test1.dat", structure_factor)
+    write_matrix_array("sk.dat", solvent.ifft.kgrid, solvent.s_k, header="S(k)")
